==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkScalarTree.java <==
// java wrapper for vtkScalarTree object
//

package vtk;
import vtk.*;

public class vtkScalarTree extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetDataSet_2(vtkDataSet id0);
  public void SetDataSet(vtkDataSet id0)
    { SetDataSet_2(id0); }

  private native long GetDataSet_3();
  public vtkDataSet GetDataSet() {
    long temp = GetDataSet_3();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetScalars_4(vtkDataArray id0);
  public void SetScalars(vtkDataArray id0)
    { SetScalars_4(id0); }

  private native long GetScalars_5();
  public vtkDataArray GetScalars() {
    long temp = GetScalars_5();

    if (temp == 0) return null;
    return (vtkDataArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void BuildTree_6();
  public void BuildTree()
    { BuildTree_6(); }

  private native void Initialize_7();
  public void Initialize()
    { Initialize_7(); }

  private native void InitTraversal_8(double id0);
  public void InitTraversal(double id0)
    { InitTraversal_8(id0); }

  private native double GetScalarValue_9();
  public double GetScalarValue()
    { return GetScalarValue_9(); }

  private native int GetNumberOfCellBatches_10();
  public int GetNumberOfCellBatches()
    { return GetNumberOfCellBatches_10(); }

  public vtkScalarTree() { super(); }

  public vtkScalarTree(long id) { super(id); }

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkScalarTree.java <==
// java wrapper for vtkScalarTree object
//

package vtk;
import vtk.*;

public class vtkScalarTree extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetDataSet_2(vtkDataSet id0);
  public void SetDataSet(vtkDataSet id0)
    { SetDataSet_2(id0); }

  private native long GetDataSet_3();
  public vtkDataSet GetDataSet() {
    long temp = GetDataSet_3();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetScalars_4(vtkDataArray id0);
  public void SetScalars(vtkDataArray id0)
    { SetScalars_4(id0); }

  private native long GetScalars_5();
  public vtkDataArray GetScalars() {
    long temp = GetScalars_5();

    if (temp == 0) return null;
    return (vtkDataArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void BuildTree_6();
  public void BuildTree()
    { BuildTree_6(); }

  private native void Initialize_7();
  public void Initialize()
    { Initialize_7(); }

  private native void InitTraversal_8(double id0);
  public void InitTraversal(double id0)
    { InitTraversal_8(id0); }

  private native double GetScalarValue_9();
  public double GetScalarValue()
    { return GetScalarValue_9(); }

  private native int GetNumberOfCellBatches_10();
  public int GetNumberOfCellBatches()
    { return GetNumberOfCellBatches_10(); }

  public vtkScalarTree() { super(); }

  public vtkScalarTree(long id) { super(id); }

}
